import { ReactNode } from "react";
import { getServerSession } from "next-auth";
import { redirect } from "next/navigation";
import { authOptions } from "../../../utils/authOptions"; // Adjust the path if needed
import AdminSidebar from "./AdminSidebar";
// Import the CSS file for control-specific styles
import "./styles/styles.css";

export default async function AdminLayout({ children }: { children: ReactNode }) {
  const session = await getServerSession(authOptions);

  if (!session || !session.user) {
    redirect("/api/auth/signin");
    return null;
  }

  if (session.user.role !== "admin" && session.user.role !== "superadmin") {
    redirect("/api/auth/signin");
    return null;
  }

  return (
    <main className="d-flex min-vh-100 bg-light" dir="rtl">
      <AdminSidebar session={session} />
      <section className="flex-grow-1 p-4">{children}</section>
    </main>
  );
}
