"use client";

import { useEffect, useState } from "react";
import { Bar } from "react-chartjs-2";
import "chart.js/auto";

export default function AdminDashboard() {
  const [analytics, setAnalytics] = useState({
    totalVisits: 0,
    totalSubmissions: 0,
    visitsThisMonth: 0,
    submissionsThisMonth: 0,
    questionStats: {},
  });
  const [loading, setLoading] = useState(true);

  useEffect(() => {
    async function fetchAnalytics() {
      try {
        const res = await fetch("/api/analytics");
        const data = await res.json();
        setAnalytics(data);
      } catch (err) {
        console.error("Error fetching analytics:", err);
      } finally {
        setLoading(false);
      }
    }

    fetchAnalytics();
  }, []);

  const renderQuestionGraphs = () => {
    const { questionStats } = analytics;
    return Object.entries(questionStats).map(([question, stats]) => {
      const labels = Object.keys(stats);
      const data = Object.values(stats);

      return (
        <div key={question} className="col-md-4 mb-4">
          <div className="card shadow-sm">
            <div className="card-body">
              <h6 className="card-title text-center">{question}</h6>
              <Bar
                data={{
                  labels,
                  datasets: [
                    {
                      label: "عدد الإجابات",
                      data,
                      backgroundColor: "rgba(54, 162, 235, 0.5)",
                      borderColor: "rgba(54, 162, 235, 1)",
                      borderWidth: 1,
                    },
                  ],
                }}
                options={{
                  responsive: true,
                  maintainAspectRatio: true,
                  plugins: {
                    legend: {
                      display: false,
                    },
                  },
                  scales: {
                    x: { ticks: { font: { size: 10 } } },
                    y: { ticks: { font: { size: 10 } } },
                  },
                }}
                height={150}
              />
            </div>
          </div>
        </div>
      );
    });
  };

  return (
    <div className="container-fluid" dir="rtl">
      <div className="row">
        <div className="col">
          <h1 className="text-primary fw-bold mt-4 mb-3">لوحة التحكم مورد</h1>
          <p className="text-muted">
            مرحبًا! استخدم الروابط في الشريط الجانبي لإدارة النماذج أو مراجعة
            السجلات.
          </p>
        </div>
      </div>

      {loading ? (
        <p>جارٍ تحميل الإحصائيات...</p>
      ) : (
        <>
          <div className="row mb-4">
            <div className="col-md-3">
              <div className="card shadow-sm">
                <div className="card-body text-center">
                  <h6 className="card-title">إجمالي الزيارات</h6>
                  <p className="display-6 text-primary">
                    {analytics.totalVisits}
                  </p>
                </div>
              </div>
            </div>
            <div className="col-md-3">
              <div className="card shadow-sm">
                <div className="card-body text-center">
                  <h6 className="card-title">إجمالي السير الذاتية المقدمة</h6>
                  <p className="display-6 text-primary">
                    {analytics.totalSubmissions}
                  </p>
                </div>
              </div>
            </div>
            <div className="col-md-3">
              <div className="card shadow-sm">
                <div className="card-body text-center">
                  <h6 className="card-title">الزيارات هذا الشهر</h6>
                  <p className="display-6 text-primary">
                    {analytics.visitsThisMonth}
                  </p>
                </div>
              </div>
            </div>
            <div className="col-md-3">
              <div className="card shadow-sm">
                <div className="card-body text-center">
                  <h6 className="card-title">السير الذاتية هذا الشهر</h6>
                  <p className="display-6 text-primary">
                    {analytics.submissionsThisMonth}
                  </p>
                </div>
              </div>
            </div>
          </div>

          <div className="row">{renderQuestionGraphs()}</div>
        </>
      )}
    </div>
  );
}
