import { NextResponse } from "next/server";
import { connectToDB } from "../../lib/db";
import Visit from "../../lib/models/visits";
import Submission from "../../lib/models/Submission";
import FormDefinition from "../../lib/models/FormDefinition";

export async function GET() {
  try {
    await connectToDB();

    // Total Visits
    const totalVisits = await Visit.countDocuments();

    // Total Submissions
    const totalSubmissions = await Submission.countDocuments();

    // Visits by Country
    const visits = await Visit.find();
    const countryVisits: Record<string, number> = {};
    visits.forEach((visit) => {
      const country = visit.country || "غير معروف"; // Replace `visit.country` if you have a real country field
      countryVisits[country] = (countryVisits[country] || 0) + 1;
    });

    // Submissions This Month
    const startOfMonth = new Date();
    startOfMonth.setDate(1);
    startOfMonth.setHours(0, 0, 0, 0);

    const submissionsThisMonth = await Submission.countDocuments({
      createdAt: { $gte: startOfMonth },
    });

    // Visits This Month
    const visitsThisMonth = await Visit.countDocuments({
      createdAt: { $gte: startOfMonth },
    });

    // Question Stats (e.g., options count for select questions)
    const formDef = await FormDefinition.findOne();
    const questionStats: Record<string, Record<string, number>> = {};

    if (formDef) {
      const submissions = await Submission.find();
      formDef.questions.forEach((question) => {
        if (question.type === "select") {
          questionStats[question.label] = {};
          submissions.forEach((submission) => {
            const answer = submission.answersArray.find(
              (ans) => ans.label === question.label
            );
            if (answer) {
              questionStats[question.label][answer.value] =
                (questionStats[question.label][answer.value] || 0) + 1;
            }
          });
        }
      });
    }

    return NextResponse.json({
      totalVisits,
      totalSubmissions,
      submissionsThisMonth,
      visitsThisMonth,
      countryVisits,
      questionStats,
    });
  } catch (error) {
    console.error("Error in /api/analytics:", error);
    return NextResponse.json({ error: error.message }, { status: 500 });
  }
}
