// app/api/logs/route.ts
import { NextResponse } from "next/server";
import { connectToDB } from "../../lib/db";
import Log from "../../lib/models/Log";

export async function GET() {
  try {
    await connectToDB();

    // Fetch logs and format the response
    const logs = await Log.find().sort({ createdAt: -1 });

    const formattedLogs = logs.map((log) => ({
      _id: log._id,
      action: log.action,
      user: log.user || "Guest User", // Correctly use the `user` field from the log
      ip: log.ip || "Unknown", // Correctly use the `ip` field from the log
      createdAt: log.createdAt,
      details: log.details || {}, // Include the details object as-is
    }));

    return NextResponse.json(formattedLogs);
  } catch (error: any) {
    console.error("Error in GET /api/logs:", error);
    return NextResponse.json({ error: error.message }, { status: 500 });
  }
}
