import { NextRequest, NextResponse } from "next/server";
import { connectToDB } from "../../lib/db";
import User from "../../lib/models/User";
import bcrypt from "bcrypt";

export async function POST(req: NextRequest) {
  try {
    await connectToDB();

    // 1) Check if there's already at least one user
    const count = await User.countDocuments();
    if (count > 0) {
      return NextResponse.json(
        {
          error: "Setup already completed. A superadmin already exists.",
        },
        { status: 400 }
      );
    }

    // 2) Parse body for username/password
    const { username, password } = await req.json();
    if (!username || !password) {
      return NextResponse.json({ error: "Missing username or password" }, { status: 400 });
    }

    // 3) Hash password
    const hashed = await bcrypt.hash(password, 10);

    // 4) Create the superadmin user with full access
    const newUser = await User.create({
      username,
      password: hashed,
      role: "superadmin", // Set the role to superadmin
      permissions: {
        formBuilder: true, // Full permissions for superadmin
      },
    });

    return NextResponse.json({
      success: true,
      message: "Superadmin created successfully",
      userId: newUser._id,
    });
  } catch (error: any) {
    console.error("Error in POST /api/setup:", error);
    return NextResponse.json({ error: error.message }, { status: 500 });
  }
}
