import { NextResponse } from "next/server";
import { connectToDB } from "../../lib/db";
import Visit from "../../lib/models/visits";

export async function POST(req: Request) {
  const { ip } = await req.json();
  if (!ip) {
    return NextResponse.json({ error: "IP address is required" }, { status: 400 });
  }

  try {
    await connectToDB();

    const existingVisit = await Visit.findOne({ ip });
    if (!existingVisit) {
      await Visit.create({ ip, createdAt: new Date() });
      console.log("New visit recorded:", ip);
    } else {
      console.log("Visit already exists for IP:", ip);
    }

    return NextResponse.json({ success: true });
  } catch (error) {
    console.error("Error tracking visit:", error);
    return NextResponse.json({ error: "Database error" }, { status: 500 });
  }
}
