"use client";

import { getCsrfToken } from "next-auth/react";
import { useState, useEffect } from "react";

export default function Login() {
  const [csrfToken, setCsrfToken] = useState<string | null>(null);

  // Fetch CSRF token on the client side
  useEffect(() => {
    async function fetchCsrfToken() {
      const token = await getCsrfToken();
      setCsrfToken(token);
    }
    fetchCsrfToken();
  }, []);

  return (
    <div
      style={{
        display: "flex",
        justifyContent: "center",
        alignItems: "center",
        height: "100vh",
        background: "linear-gradient(to top,rgb(217, 235, 255),rgb(255, 255, 255)",
        direction: "rtl",
      }}
    >
      <form
        method="post"
        action="/api/auth/callback/credentials"
        style={{
          width: "700px",
          padding: "20px",
          borderRadius: "10px",
          backgroundColor: "#fff",
          boxShadow: "0px 4px 20px rgba(0, 0, 0, 0.1)",
          textAlign: "center",
        }}
      >
        {/* Logo */}
        <div style={{ marginBottom: "20px" }}>
          <img
            src="/images/logo-light.png" // Replace with the path to your logo
            alt="Logo"
            style={{ maxWidth: "150px", objectFit: "contain" }}
          />
        </div>

        {/* CSRF Token */}
        <input name="csrfToken" type="hidden" defaultValue={csrfToken || ""} />

        {/* Title */}
        <h2 style={{ marginBottom: "20px", color: "#333", fontWeight: "bold" }}>تسجيل الدخول للوحة التحكم</h2>

        {/* Username */}
        <div style={{ marginBottom: "15px", textAlign: "right" }}>
          <label style={{ display: "block", fontWeight: "500", marginBottom: "5px" }}>
            اسم المستخدم
          </label>
          <input
            name="username"
            type="text"
            style={{
              display: "block",
              width: "100%",
              padding: "10px",
              border: "1px solid #ddd",
              borderRadius: "5px",
            }}
          />
        </div>

        {/* Password */}
        <div style={{ marginBottom: "20px", textAlign: "right" }}>
          <label style={{ display: "block", fontWeight: "500", marginBottom: "5px" }}>
            كلمة المرور
          </label>
          <input
            name="password"
            type="password"
            style={{
              display: "block",
              width: "100%",
              padding: "10px",
              border: "1px solid #ddd",
              borderRadius: "5px",
            }}
          />
        </div>

        {/* Submit Button */}
        <button
          type="submit"
          style={{
            width: "100%",
            padding: "10px",
            backgroundColor: "#00adef",
            color: "#fff",
            border: "none",
            borderRadius: "5px",
            fontWeight: "bold",
            cursor: "pointer",
            transition: "background-color 0.3s ease",
          }}
          onMouseEnter={(e) => (e.currentTarget.style.backgroundColor = "#007bb5")}
          onMouseLeave={(e) => (e.currentTarget.style.backgroundColor = "#00adef")}
        >
          تسجيل الدخول
        </button>
      </form>
    </div>
  );
}
