// lib/rateLimiter.ts

type RateInfo = {
    count: number;
    firstRequestTime: number;
  };
  
  const requestsMap = new Map<string, RateInfo>(); // IP -> RateInfo
  const TIME_WINDOW = 15 * 60 * 1000; // 15 minutes
  const MAX_REQUESTS = 10;           // Max submissions in the time window
  
  export function checkRateLimit(ip: string): boolean {
    const now = Date.now();
    const rateInfo = requestsMap.get(ip);
  
    if (!rateInfo) {
      // First request from this IP
      requestsMap.set(ip, { count: 1, firstRequestTime: now });
      return true; // allowed
    }
  
    // If within the same time window
    if (now - rateInfo.firstRequestTime < TIME_WINDOW) {
      // If already exceeded
      if (rateInfo.count >= MAX_REQUESTS) {
        return false; // blocked
      } else {
        rateInfo.count += 1;
        requestsMap.set(ip, rateInfo);
        return true;
      }
    } else {
      // Window has expired, reset
      requestsMap.set(ip, { count: 1, firstRequestTime: now });
      return true;
    }
  }
  